@@ -1,9 +1,9 @@
 """
 zfec -- fast forward error correction library with Python interface
 
-maintainer web site: U{http://allmydata.com/source/zfec}
+maintainer web site: U{http://tahoe-lafs.org/source/zfec}
 
-zfec web site: U{http://allmydata.com/source/zfec}
+zfec web site: U{http://tahoe-lafs.org/source/zfec}
 """
 
 __version__ = "unknown"
@@ -21,11 +21,11 @@ import easyfec, filefec, cmdline_zfec, cmdline_zunfec
 quiet_pyflakes=[__version__, Error, Encoder, Decoder, cmdline_zunfec, filefec, cmdline_zfec, easyfec]
 
 # zfec -- fast forward error correction library with Python interface
-# 
-# Copyright (C) 2007 Allmydata, Inc.
+#
+# Copyright (C) 2007-2010 Allmydata, Inc.
 # Author: Zooko Wilcox-O'Hearn
 # mailto:zooko@zooko.com
-# 
+#
 # This file is part of zfec.
 #
-# See README.txt for licensing information.
+# See README.rst for licensing information.
